pub mod err;
pub mod cli;

pub use err::*;
pub use cli::*;

#[cfg(test)]
mod tests {
    use super::*;

    #[test]
    fn test_err() {
        let use_new = BasicError::new();

        assert_eq!(use_new.clone(), BasicError::new());
        assert_eq!(use_new.to_string(), "error".to_string());
        
        let use_str = BasicError::from("using &str");

        assert_eq!(use_str.clone(), BasicError::from("using &str"));
        assert_eq!(use_str.to_string(), "using &str".to_string());

        let use_string = BasicError::from("using String".to_string());

        assert_eq!(use_string.clone(), BasicError::from("using String"));
        assert_eq!(use_string.to_string(), "using String".to_string());
    }

    #[test]
    fn test_cli() {
        let mut cli = CLI::new("test_cli");

        cli.println("title", "message");
        cli.eprintln("title", "message");

        assert_eq!(cli.clone_history(), vec!["message".to_string(), "message".to_string()]);
    }
}
